@@ -11,7 +11,7 @@ require 'monitoring/monitoring'
 
 shared_examples "elasticsearch options hash is populated without security" do
   it "with username, hosts and password" do
-      expect(test_class.es_options_from_settings_or_modules('monitoring', system_settings)).to include(
+      expect(test_class.es_options_from_settings('monitoring', system_settings)).to include(
                                                                                                    "hosts" => expected_url,
                                                                                                    "user" => expected_username,
                                                                                                    "password" => expected_password
@@ -29,8 +29,23 @@ shared_examples 'elasticsearch options hash is populated with secure options' do
                                                                                         "hosts" => elasticsearch_url,
                                                                                         "user" => elasticsearch_username,
                                                                                         "password" => elasticsearch_password,
-                                                                                        "ssl" => true,
-                                                                                        "cacert" => elasticsearch_ca
+                                                                                        "ssl_enabled" => true,
+                                                                                        "ssl_certificate_authorities" => elasticsearch_ca
+                                                                                    )
+    end
+  end
+
+  context "with ca_trusted_fingerprint" do
+    let(:ca_trusted_fingerprint) { SecureRandom.hex(32) }
+    let(:settings) { super().merge("xpack.monitoring.elasticsearch.ssl.ca_trusted_fingerprint" => ca_trusted_fingerprint) }
+
+    it "creates the elasticsearch output options hash" do
+      expect(test_class.es_options_from_settings('monitoring', system_settings)).to include(
+                                                                                      "hosts" => elasticsearch_url,
+                                                                                      "user" => elasticsearch_username,
+                                                                                      "password" => elasticsearch_password,
+                                                                                      "ssl_enabled" => true,
+                                                                                      "ca_trusted_fingerprint" => ca_trusted_fingerprint
                                                                                     )
     end
   end
@@ -50,9 +65,9 @@ shared_examples 'elasticsearch options hash is populated with secure options' do
                                                                                         "hosts" => elasticsearch_url,
                                                                                         "user" => elasticsearch_username,
                                                                                         "password" => elasticsearch_password,
-                                                                                        "ssl" => true,
-                                                                                        "truststore" => elasticsearch_truststore_path,
-                                                                                        "truststore_password" => elasticsearch_truststore_password
+                                                                                        "ssl_enabled" => true,
+                                                                                        "ssl_truststore_path" => elasticsearch_truststore_path,
+                                                                                        "ssl_truststore_password" => elasticsearch_truststore_password
                                                                                     )
     end
   end
@@ -73,12 +88,67 @@ shared_examples 'elasticsearch options hash is populated with secure options' do
                                                                                         "hosts" => elasticsearch_url,
                                                                                         "user" => elasticsearch_username,
                                                                                         "password" => elasticsearch_password,
-                                                                                        "ssl" => true,
-                                                                                        "keystore" => elasticsearch_keystore_path,
-                                                                                        "keystore_password" => elasticsearch_keystore_password
+                                                                                        "ssl_enabled" => true,
+                                                                                        "ssl_keystore_path" => elasticsearch_keystore_path,
+                                                                                        "ssl_keystore_password" => elasticsearch_keystore_password
                                                                                     )
     end
   end
+
+  context "with certificate and key" do
+    let(:elasticsearch_certificate_path) { Stud::Temporary.file.path }
+    let(:elasticsearch_key_path) { Stud::Temporary.file.path }
+
+    let(:settings) do
+      super().merge({
+        "xpack.monitoring.elasticsearch.ssl.certificate" => elasticsearch_certificate_path,
+        "xpack.monitoring.elasticsearch.ssl.key" => elasticsearch_key_path,
+      })
+    end
+
+    it "creates the elasticsearch output options hash" do
+      expect(test_class.es_options_from_settings('monitoring', system_settings)).to include(
+                                                                                        "hosts" => elasticsearch_url,
+                                                                                        "user" => elasticsearch_username,
+                                                                                        "password" => elasticsearch_password,
+                                                                                        "ssl_enabled" => true,
+                                                                                        "ssl_certificate" => elasticsearch_certificate_path,
+                                                                                        "ssl_key" => elasticsearch_key_path
+                                                                                      )
+    end
+  end
+
+  context "with cipher suites" do
+    context "provided" do
+      let(:settings) do
+        super().merge({
+          "xpack.monitoring.elasticsearch.ssl.cipher_suites" => ["FOO", "BAR"],
+        })
+      end
+
+      it "creates the elasticsearch output options hash" do
+        expect(test_class.es_options_from_settings('monitoring', system_settings)).to include(
+                                                                                          "hosts" => elasticsearch_url,
+                                                                                          "user" => elasticsearch_username,
+                                                                                          "password" => elasticsearch_password,
+                                                                                          "ssl_enabled" => true,
+                                                                                          "ssl_cipher_suites" => ["FOO", "BAR"],
+                                                                                        )
+      end
+    end
+
+    context "empty" do
+      let(:settings) do
+        super().merge({
+          "xpack.monitoring.elasticsearch.ssl.cipher_suites" => [],
+        })
+      end
+
+      it "creates the elasticsearch output options hash" do
+        expect(test_class.es_options_from_settings('monitoring', system_settings)).to_not have_key("ssl_cipher_suites")
+      end
+    end
+  end
 end
 
 describe LogStash::Helpers::ElasticsearchOptions do
@@ -98,7 +168,6 @@ describe LogStash::Helpers::ElasticsearchOptions do
   end
 
   describe "es_options_from_settings" do
-
     context "with implicit username" do
       let(:settings) do
         {
@@ -109,7 +178,7 @@ describe LogStash::Helpers::ElasticsearchOptions do
 
       it "ignores the implicit default username when no password is set" do
         # when no explicit password is set then the default/implicit username should be ignored
-        es_options = test_class.es_options_from_settings_or_modules('monitoring', system_settings)
+        es_options = test_class.es_options_from_settings('monitoring', system_settings)
         expect(es_options).to_not include("user")
         expect(es_options).to_not include("password")
       end
@@ -126,13 +195,12 @@ describe LogStash::Helpers::ElasticsearchOptions do
         end
 
         it "silently ignores the default username" do
-          es_options = test_class.es_options_from_settings_or_modules('monitoring', system_settings)
+          es_options = test_class.es_options_from_settings('monitoring', system_settings)
           expect(es_options).to include("cloud_auth")
           expect(es_options).to_not include("user")
         end
       end
 
-
       context "with api_key" do
         let(:settings) do
           super().merge(
@@ -141,7 +209,7 @@ describe LogStash::Helpers::ElasticsearchOptions do
         end
 
         it "silently ignores the default username" do
-          es_options = test_class.es_options_from_settings_or_modules('monitoring', system_settings)
+          es_options = test_class.es_options_from_settings('monitoring', system_settings)
           expect(es_options).to include("api_key")
           expect(es_options).to_not include("user")
         end
@@ -155,7 +223,7 @@ describe LogStash::Helpers::ElasticsearchOptions do
 
           it "fails for multiple authentications" do
             expect {
-              test_class.es_options_from_settings_or_modules('monitoring', system_settings)
+              test_class.es_options_from_settings('monitoring', system_settings)
             }.to raise_error(ArgumentError, /Multiple authentication options are specified/)
           end
         end
@@ -173,7 +241,7 @@ describe LogStash::Helpers::ElasticsearchOptions do
 
       it "fails without password" do
         expect {
-          test_class.es_options_from_settings_or_modules('monitoring', system_settings)
+          test_class.es_options_from_settings('monitoring', system_settings)
         }.to raise_error(ArgumentError, /password must also be set/)
       end
 
@@ -187,7 +255,7 @@ describe LogStash::Helpers::ElasticsearchOptions do
 
         it "fails for multiple authentications" do
           expect {
-            test_class.es_options_from_settings_or_modules('monitoring', system_settings)
+            test_class.es_options_from_settings('monitoring', system_settings)
           }.to raise_error(ArgumentError, /Both.*?cloud_auth.*?and.*?username.*?specified/)
         end
       end
@@ -202,7 +270,7 @@ describe LogStash::Helpers::ElasticsearchOptions do
 
         it "fails for multiple authentications" do
           expect {
-            test_class.es_options_from_settings_or_modules('monitoring', system_settings)
+            test_class.es_options_from_settings('monitoring', system_settings)
           }.to raise_error(ArgumentError, /Multiple authentication options are specified/)
         end
       end
@@ -222,7 +290,6 @@ describe LogStash::Helpers::ElasticsearchOptions do
       it_behaves_like 'elasticsearch options hash is populated with secure options'
     end
 
-
     context 'when cloud_id' do
       let(:cloud_name) { 'thebigone'}
       let(:cloud_domain) { 'elastic.co'}
@@ -244,7 +311,7 @@ describe LogStash::Helpers::ElasticsearchOptions do
 
         it "raises due invalid configuration" do
           expect {
-            test_class.es_options_from_settings_or_modules('monitoring', system_settings)
+            test_class.es_options_from_settings('monitoring', system_settings)
            }.to raise_error(ArgumentError, /Both.*?cloud_id.*?and.*?hosts.*?specified/)
         end
       end
@@ -260,7 +327,7 @@ describe LogStash::Helpers::ElasticsearchOptions do
         end
 
         it "creates the elasticsearch output options hash" do
-          es_options = test_class.es_options_from_settings_or_modules('monitoring', system_settings)
+          es_options = test_class.es_options_from_settings('monitoring', system_settings)
           expect(es_options).to include("cloud_id" => cloud_id, "cloud_auth" => cloud_auth)
           expect(es_options.keys).to_not include("hosts")
           expect(es_options.keys).to_not include("username")
@@ -276,7 +343,7 @@ describe LogStash::Helpers::ElasticsearchOptions do
 
           it "raises for invalid configuration" do
             expect {
-              test_class.es_options_from_settings_or_modules('monitoring', system_settings)
+              test_class.es_options_from_settings('monitoring', system_settings)
             }.to raise_error(ArgumentError, /Both.*?cloud_auth.*?and.*?username.*?specified/)
           end
         end
@@ -290,7 +357,7 @@ describe LogStash::Helpers::ElasticsearchOptions do
 
           it "raises for invalid configuration" do
             expect {
-              test_class.es_options_from_settings_or_modules('monitoring', system_settings)
+              test_class.es_options_from_settings('monitoring', system_settings)
             }.to raise_error(ArgumentError, /Multiple authentication options are specified/)
           end
         end
@@ -298,7 +365,7 @@ describe LogStash::Helpers::ElasticsearchOptions do
 
       context "when cloud_auth is not set" do
         it "does not use authentication and ignores the default username" do
-          es_options = test_class.es_options_from_settings_or_modules('monitoring', system_settings)
+          es_options = test_class.es_options_from_settings('monitoring', system_settings)
           expect(es_options).to include("cloud_id")
           expect(es_options.keys).to_not include("hosts", "user", "password")
         end
@@ -312,7 +379,7 @@ describe LogStash::Helpers::ElasticsearchOptions do
           end
 
           it "creates the elasticsearch output options hash" do
-            es_options = test_class.es_options_from_settings_or_modules('monitoring', system_settings)
+            es_options = test_class.es_options_from_settings('monitoring', system_settings)
             expect(es_options).to include("cloud_id", "user", "password")
             expect(es_options.keys).to_not include("hosts")
           end
@@ -326,7 +393,7 @@ describe LogStash::Helpers::ElasticsearchOptions do
           end
 
           it "creates the elasticsearch output options hash" do
-            es_options = test_class.es_options_from_settings_or_modules('monitoring', system_settings)
+            es_options = test_class.es_options_from_settings('monitoring', system_settings)
             expect(es_options).to include("cloud_id", "api_key")
             expect(es_options.keys).to_not include("hosts")
           end
@@ -345,7 +412,7 @@ describe LogStash::Helpers::ElasticsearchOptions do
       end
 
       it "creates the elasticsearch output options hash" do
-        es_options = test_class.es_options_from_settings_or_modules('monitoring', system_settings)
+        es_options = test_class.es_options_from_settings('monitoring', system_settings)
         expect(es_options).to include("api_key" => api_key)
         expect(es_options.keys).to include("hosts")
       end
@@ -355,14 +422,14 @@ describe LogStash::Helpers::ElasticsearchOptions do
 
         it "fails at options validation" do
           expect {
-            test_class.es_options_from_settings_or_modules('monitoring', system_settings)
+            test_class.es_options_from_settings('monitoring', system_settings)
           }.to raise_error(ArgumentError, /api_key authentication requires SSL\/TLS/)
         end
       end
     end
   end
 
-  describe 'es_options_from_settings_or_modules' do
+  describe 'es_options_from_settings' do
     context 'when only settings are set' do
       let(:settings) do
         {
@@ -376,113 +443,5 @@ describe LogStash::Helpers::ElasticsearchOptions do
       it_behaves_like 'elasticsearch options hash is populated without security'
       it_behaves_like 'elasticsearch options hash is populated with secure options'
     end
-
-    context 'with modules set' do
-      let(:modules_es_url) { ["https://localhost:9898", "https://localhost:9999"]}
-      let(:modules_es_username) { "modules_user"}
-      let(:modules_es_password) { "correcthorsebatterystaple"}
-
-      context 'when only modules cli are set' do
-        let(:expected_url) { modules_es_url }
-        let(:expected_username) { modules_es_username }
-        let(:expected_password) { modules_es_password }
-        let(:settings) { {"modules.cli" => [{ "name" => "hello",
-                                                          'var.elasticsearch.hosts' => modules_es_url,
-                                                          'var.elasticsearch.username' => modules_es_username,
-                                                          'var.elasticsearch.password' => modules_es_password}]}
-        }
-
-        it_behaves_like 'elasticsearch options hash is populated without security'
-      end
-
-      context 'when only modules yaml are set' do
-        let(:expected_url) { modules_es_url }
-        let(:expected_username) { modules_es_username }
-        let(:expected_password) { modules_es_password }
-        let(:settings) { {"modules" => [{ "name" => "hello",
-                                              'var.elasticsearch.hosts' => modules_es_url,
-                                              'var.elasticsearch.username' => modules_es_username,
-                                              'var.elasticsearch.password' => modules_es_password}]}
-        }
-
-        it_behaves_like 'elasticsearch options hash is populated without security'
-      end
-
-      context 'when cloud id and auth are set' do
-        let(:cloud_name) { 'thebigone'}
-        let(:cloud_domain) { 'elastic.co'}
-        let(:base64_encoded) { Base64.urlsafe_encode64("#{cloud_domain}$#{cloud_name}$ignored")}
-        let(:cloud_id) { "label:#{base64_encoded}" }
-        let(:cloud_username) { 'cloudy' }
-        let(:cloud_password) { 'cloud_password'}
-        let(:expected_url) { ["https://#{cloud_name}.#{cloud_domain}:443"] }
-        let(:expected_username) { cloud_username }
-        let(:expected_password) { cloud_password }
-        let(:settings) {
-          {
-              "cloud.id" => cloud_id,
-              "cloud.auth" => "#{cloud_username}:#{cloud_password}",
-              "modules" => [{ "name" => "hello",
-                                          'var.elasticsearch.hosts' => modules_es_url,
-                                          'var.elasticsearch.username' => modules_es_username,
-                                          'var.elasticsearch.password' => modules_es_password}]}
-        }
-
-        it_behaves_like 'elasticsearch options hash is populated without security'
-      end
-
-      context 'when only modules cli and yaml are set' do
-        let(:modules_cli_url) { ['cli:9200']}
-        let(:modules_cli_username) { 'cli_user' }
-        let(:modules_cli_password) { 'cli_password'}
-        let(:expected_url) { modules_cli_url }
-        let(:expected_username) { modules_cli_username }
-        let(:expected_password) { modules_cli_password }
-        let(:settings) { {"modules.cli" => [{ "name" => "hello",
-                                              'var.elasticsearch.hosts' => modules_cli_url,
-                                              'var.elasticsearch.username' => modules_cli_username,
-                                              'var.elasticsearch.password' => modules_cli_password}],
-                          "modules" => [{ "name" => "hello",
-                                           'var.elasticsearch.hosts' => modules_es_url,
-                                           'var.elasticsearch.username' => modules_es_username,
-                                           'var.elasticsearch.password' => modules_es_password}]}
-        }
-
-        it_behaves_like 'elasticsearch options hash is populated without security'
-      end
-
-
-      context 'when everything is set' do
-        let(:cloud_name) { 'thebigone'}
-        let(:cloud_domain) { 'elastic.co'}
-        let(:base64_encoded) { Base64.urlsafe_encode64("#{cloud_domain}$#{cloud_name}$ignored")}
-        let(:cloud_id) { "label:#{base64_encoded}" }
-        let(:cloud_username) { 'cloudy' }
-        let(:cloud_password) { 'cloud_password'}
-        let(:modules_cli_url) { ['cli:9200']}
-        let(:modules_cli_username) { 'cli_user' }
-        let(:modules_cli_password) { 'cli_password'}
-        let(:settings) do
-          { "modules" => [{ "name" => "hello",
-                            'var.elasticsearch.hosts' => modules_es_url,
-                            'var.elasticsearch.username' => modules_es_username,
-                            'var.elasticsearch.password' => modules_es_password}],
-            "modules.cli" => [{ "name" => "hello",
-                                 'var.elasticsearch.hosts' => modules_cli_url,
-                                 'var.elasticsearch.username' => modules_cli_username,
-                                 'var.elasticsearch.password' => modules_cli_password}],
-            "cloud.id" => cloud_id,
-            "cloud.auth" => "#{cloud_username}:#{cloud_password}",
-            "xpack.monitoring.enabled" => true,
-            "xpack.monitoring.elasticsearch.hosts" => elasticsearch_url,
-            "xpack.monitoring.elasticsearch.username" => elasticsearch_username,
-            "xpack.monitoring.elasticsearch.password" => elasticsearch_password,
-          }
-        end
-
-        it_behaves_like 'elasticsearch options hash is populated without security'
-        it_behaves_like 'elasticsearch options hash is populated with secure options'
-      end
-    end
   end
 end
